@@ -452,12 +452,12 @@ end
 
 @testset "checked operations" begin
     for X in XInts
-        if sizeof(X) != 3 # bug with [U]Int24, cf. Julia issue #34288
+        if VERSION >= v"1.8" || sizeof(X) != 3 # bug with [U]Int24, cf. Julia issue #34288
             @test Base.sub_with_overflow(typemin(X)+X(3), X(3)) == (typemin(X), false)
             @test Base.sub_with_overflow(typemin(X)+X(2), X(3)) == (typemax(X), true)
             @test Base.add_with_overflow(typemax(X)-X(3), X(3)) == (typemax(X), false)
             @test Base.add_with_overflow(typemax(X)-X(2), X(3)) == (typemin(X), true)
-            if X <: Signed # unimplemented otherwise (problem with LLVM)
+            if VERSION >= v"1.11-" || X <: Signed # unimplemented otherwise (problem with LLVM)
                 @test Base.mul_with_overflow(typemax(X), X(1))  == (typemax(X), false)
                 @test Base.mul_with_overflow(typemax(X), X(2))  == (-2 % X,     true)
             end
